@@ -17,7 +17,6 @@ use rayon::iter::{
 };
 use std::{
 	collections::HashSet,
-	convert::TryFrom,
 	fmt,
 	fs::{
 		self,
@@ -87,7 +86,6 @@ impl DowserError {
 ///
 /// ```no_run
 /// use dowser::Dowser;
-/// use std::convert::TryFrom;
 /// use std::os::unix::ffi::OsStrExt;
 /// use std::path::{Path, PathBuf};
 ///
@@ -151,7 +149,6 @@ impl TryFrom<Dowser> for Vec<PathBuf> {
 	///
 	/// ```no_run
 	/// use dowser::Dowser;
-	/// use std::convert::TryFrom;
 	/// use std::path::PathBuf;
 	///
 	/// let files = Vec::<PathBuf>::try_from(
@@ -212,7 +209,6 @@ impl Dowser {
 	///
 	/// ```ignore
 	/// use dowser::Dowser;
-	/// use std::convert::TryFrom;
 	/// use std::path::PathBuf;
 	///
 	/// let files = Vec::<PathBuf>::try_from(
@@ -249,7 +245,6 @@ impl Dowser {
 	///
 	/// ```no_run
 	/// use dowser::Dowser;
-	/// use std::convert::TryFrom;
 	/// use std::path::PathBuf;
 	///
 	/// let files = Vec::<PathBuf>::try_from(
@@ -278,11 +273,17 @@ impl Dowser {
 	/// results if they pass (i.e. immediately). Directories will be queued for
 	/// later scanning (i.e. during collection).
 	///
+	/// ## Warning
+	///
+	/// The source paths are meant to be paths, _plural_. Pass an iterator,
+	/// slice, or collection to it, _not_ a singular `Path`/`PathBuf`. If you
+	/// want to add a single path, use [`Dowser::with_path`] instead, or
+	/// enclose the value in a slice, like `with_paths([val])`.
+	///
 	/// ## Examples
 	///
 	/// ```no_run
 	/// use dowser::Dowser;
-	/// use std::convert::TryFrom;
 	/// use std::path::PathBuf;
 	///
 	/// let files = Vec::<PathBuf>::try_from(
@@ -307,7 +308,6 @@ impl Dowser {
 	///
 	/// ```no_run
 	/// use dowser::Dowser;
-	/// use std::convert::TryFrom;
 	/// use std::path::PathBuf;
 	///
 	/// let files = Vec::<PathBuf>::try_from(
